//// Flux Limiter method - Transport equation
//// Periodic boundary conditions 
//// Phi is the function defining the flux limiter
function[ufinal]=FluxLimiter(T,dt,L,dx,uinit,a,Phi)
     //// Time discretization
    time=0:dt:T;
    Nt=length(time);
    //// Space discretization COLUMN vector
    space=(0:dx:L)';
  //// Initial datum - We calculate on N-1 points 
    u=uinit(1:$-1);
  //// Computation of the velocity 
    vel=a(space(1:$-1));
    //// Computations of vectors velp(i)=a(x_{i+1}) and velm(i)=a(x_{i-1})
      velp=[vel(2:$);vel(1)];
      velm=[vel($);vel(1:$-1)];  
  //// Flux Limiter method
  for i=1:Nt
      //// Periodic boundary conditions
      //// Computation of vectors up(i)=u_{i+1}, um(i)=u_(i-1)
      up=[u(2:$);u(1)];
      um=[u($);u(1:$-1)];
      umm=[u($-1:$);u(1:$-2)];
      //// Flux limiters- Careful  when up=u or um=u
      Phip=zeros(u);Phim=zeros(u);
      indices1=(up==u); indices2=(up~=u);
      Phip(indices1)=0;
      teta=(u(indices2)-um(indices2))./(up(indices2)-u(indices2));
      Phip(indices2)=Phi(teta);
      indices1m=(u==um); indices2m=(u~=um);
      Phim(indices1m)=0; Phim(indices2m)=Phi((um(indices2m)-umm(indices2m))./(u(indices2m)-um(indices2m)));
            //// computation of flux
      Fp=vel.*(u+up)/2-abs(vel).*(up-u)/2+abs(vel).*(ones(vel)-abs(vel)*dt/dx).*(up-u).*Phip/2;
      Fm=velm.*(um+u)/2-abs(velm).*(u-um)/2+abs(velm).*(ones(velm)-abs(velm)*dt/dx).*(u-um).*Phim/2;
      u=u-dt/dx*(Fp-Fm);  
  end
   ufinal=[u;u(1)];
   endfunction
