//// Flux Limiter method - Conservation law
//// Periodic boundary conditions 
//// Phi is the function defining the flux limiter
function[ufinal]=FluxLimiterNL(T,dt,L,dx,uinit,f,a,Phi)
     //// Time discretization
    time=0:dt:T;
    Nt=length(time);
    //// Space discretization COLUMN vector
    space=(0:dx:L)';
  //// Initial datum - We calculate on N-1 points 
    u=uinit(1:$-1);
  //// Flux Limiter method
  for i=1:Nt
      //// Periodic boundary conditions
      //// Computation of vectors up(i)=u_{i+1}, um(i)=u_(i-1)
      up=[u(2:$);u(1)];
      um=[u($);u(1:$-1)];
      umm=[u($-1:$);u(1:$-2)];
      //// Difference of functions
      Dfp=f(up)-f(u);
      Df=f(u)-f(um);
      Dfm=f(um)-f(umm);
      //// Velocities
       velp=zeros(u);vel=zeros(u);velm=zeros(u);
      indices1=(up==u); indices2=(up~=u);
      velp(indices1)=a(u(indices1));
      velp(indices2)=(f(up(indices2))-f(u(indices2)))./(up(indices2)-u(indices2));
      indices1m=(u==um); indices2m=(u~=um);
      vel(indices1m)=a(um(indices1m));
      vel(indices2m)=(f(u(indices2m))-f(um(indices2m)))./(u(indices2m)-um(indices2m));
      indices1mm=(um==umm); indices2mm=(um~=umm);
      velm(indices1mm)=a(umm(indices1mm));
      velm(indices2mm)=(f(um(indices2mm))-f(umm(indices2mm)))./(um(indices2mm)-umm(indices2mm));
      //// Limiters
      Phip=zeros(u);Phim=zeros(u);
      indices1f=(f(up)==f(u)); indices2f=(f(up)~=f(u));
      Tetap=(ones(vel(indices2f))-dt*vel(indices2f)/dx)./(ones(velp(indices2f))-dt*velp(indices2f)/dx).*Df(indices2f)./Dfp(indices2f);
      Phip(indices2f)=Phi(Tetap); Phip(indices1f)=0; 
      indices1mf=(f(u)==f(um)); indices2mf=(f(u)~=f(um));
      Tetam=(ones(velm(indices2mf))-dt*velm(indices2mf)/dx)./(ones(vel(indices2mf))-dt*vel(indices2mf)/dx).*Dfm(indices2mf)./Df(indices2mf);
      Phim(indices2mf)=Phi(Tetam); Phim(indices1mf)=0; 
      //// computation of flux
      Fp=f(u)+Dfp.*(ones(velp)-dt*velp/dx).*Phip/2;
      Fm=f(um)+Df.*(ones(vel)-dt*vel/dx).*Phim/2;
      u=u-dt/dx*(Fp-Fm);  
  end
   ufinal=[u;u(1)];
   endfunction
   
